<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => ':count metus|:count metus|:count metų',
    'y' => ':count metus|:count metus|:count metų',
    'month' => ':count mėnesį|:count mėnesius|:count mėnesių',
    'm' => ':count mėnesį|:count mėnesius|:count mėnesių',
    'week' => ':count savaitę|:count savaites|:count savaičių',
    'w' => ':count savaitę|:count savaites|:count savaičių',
    'day' => ':count dieną|:count dienas|:count dienų',
    'd' => ':count dieną|:count dienas|:count dienų',
    'hour' => ':count valandą|:count valandas|:count valandų',
    'h' => ':count valandą|:count valandas|:count valandų',
    'minute' => ':count minutę|:count minutes|:count minučių',
    'min' => ':count minutę|:count minutes|:count minučių',
    'second' => ':count sekundę|:count sekundes|:count sekundžių',
    's' => ':count sekundę|:count sekundes|:count sekundžių',
    'second_from_now' => ':count sekundės|:count sekundžių|:count sekundžių',
    'minute_from_now' => ':count minutės|:count minučių|:count minučių',
    'hour_from_now' => ':count valandos|:count valandų|:count valandų',
    'day_from_now' => ':count dienos|:count dienų|:count dienų',
    'week_from_now' => ':count savaitės|:count savaičių|:count savaičių',
    'month_from_now' => ':count mėnesio|:count mėnesių|:count mėnesių',
    'year_from_now' => ':count metų',
    'ago' => 'prieš :time',
    'from_now' => 'už :time',
    'after' => 'po :time',
    'before' => ':time nuo dabar',
);
