<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => 'שנה|{2}שנתיים|:count שנים',
    'y' => 'שנה|{2}שנתיים|:count שנים',
    'month' => 'חודש|{2}חודשיים|:count חודשים',
    'm' => 'חודש|{2}חודשיים|:count חודשים',
    'week' => 'שבוע|{2}שבועיים|:count שבועות',
    'w' => 'שבוע|{2}שבועיים|:count שבועות',
    'day' => 'יום|{2}יומיים|:count ימים',
    'd' => 'יום|{2}יומיים|:count ימים',
    'hour' => 'שעה|{2}שעתיים|:count שעות',
    'h' => 'שעה|{2}שעתיים|:count שעות',
    'minute' => 'דקה|{2}דקותיים|:count דקות',
    'min' => 'דקה|{2}דקותיים|:count דקות',
    'second' => 'שניה|:count שניות',
    's' => 'שניה|:count שניות',
    'ago' => 'לפני :time',
    'from_now' => 'בעוד :time',
    'after' => 'אחרי :time',
    'before' => 'לפני :time',
);
