<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => ':count տարի',
    'y' => ':countտ',
    'month' => ':count ամիս',
    'm' => ':countամ',
    'week' => ':count շաբաթ',
    'w' => ':countշ',
    'day' => ':count օր',
    'd' => ':countօր',
    'hour' => ':count ժամ',
    'h' => ':countժ',
    'minute' => ':count րոպե',
    'min' => ':countր',
    'second' => ':count վարկյան',
    's' => ':countվրկ',
    'ago' => ':time առաջ',
    'from_now' => ':time ներկա պահից',
    'after' => ':time հետո',
    'before' => ':time առաջ',
);
