<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => ':count کال|:count کاله',
    'y' => ':countکال|:countکاله',
    'month' => ':count مياشت|:count مياشتي',
    'm' => ':countمياشت|:countمياشتي',
    'week' => ':count اونۍ|:count اونۍ',
    'w' => ':countاونۍ|:countاونۍ',
    'day' => ':count ورځ|:count ورځي',
    'd' => ':countورځ|:countورځي',
    'hour' => ':count ساعت|:count ساعته',
    'h' => ':countساعت|:countساعته',
    'minute' => ':count دقيقه|:count دقيقې',
    'min' => ':countدقيقه|:countدقيقې',
    'second' => ':count ثانيه|:count ثانيې',
    's' => ':countثانيه|:countثانيې',
    'ago' => ':time دمخه',
    'from_now' => ':time له اوس څخه',
    'after' => ':time وروسته',
    'before' => ':time دمخه',
);
