<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => ':count rok|:count roky|:count let',
    'y' => ':count rok|:count roky|:count let',
    'month' => ':count měsíc|:count měsíce|:count měsíců',
    'm' => ':count měsíc|:count měsíce|:count měsíců',
    'week' => ':count týden|:count týdny|:count týdnů',
    'w' => ':count týden|:count týdny|:count týdnů',
    'day' => ':count den|:count dny|:count dní',
    'd' => ':count den|:count dny|:count dní',
    'hour' => ':count hodinu|:count hodiny|:count hodin',
    'h' => ':count hodinu|:count hodiny|:count hodin',
    'minute' => ':count minutu|:count minuty|:count minut',
    'min' => ':count minutu|:count minuty|:count minut',
    'second' => ':count sekundu|:count sekundy|:count sekund',
    's' => ':count sekundu|:count sekundy|:count sekund',
    'ago' => ':time nazpět',
    'from_now' => 'za :time',
    'after' => ':time později',
    'before' => ':time předtím',
);
