<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => '1 ár|:count ár',
    'y' => '1 ár|:count ár',
    'month' => '1 mánuður|:count mánuðir',
    'm' => '1 mánuður|:count mánuðir',
    'week' => '1 vika|:count vikur',
    'w' => '1 vika|:count vikur',
    'day' => '1 dagur|:count dagar',
    'd' => '1 dagur|:count dagar',
    'hour' => '1 klukkutími|:count klukkutímar',
    'h' => '1 klukkutími|:count klukkutímar',
    'minute' => '1 mínúta|:count mínútur',
    'min' => '1 mínúta|:count mínútur',
    'second' => '1 sekúnda|:count sekúndur',
    's' => '1 sekúnda|:count sekúndur',
    'ago' => ':time síðan',
    'from_now' => ':time síðan',
    'after' => ':time eftir',
    'before' => ':time fyrir',
);
