<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => '১ বছর|:count বছর',
    'y' => '১ বছর|:count বছর',
    'month' => '১ মাস|:count মাস',
    'm' => '১ মাস|:count মাস',
    'week' => '১ সপ্তাহ|:count সপ্তাহ',
    'w' => '১ সপ্তাহ|:count সপ্তাহ',
    'day' => '১ দিন|:count দিন',
    'd' => '১ দিন|:count দিন',
    'hour' => '১ ঘন্টা|:count ঘন্টা',
    'h' => '১ ঘন্টা|:count ঘন্টা',
    'minute' => '১ মিনিট|:count মিনিট',
    'min' => '১ মিনিট|:count মিনিট',
    'second' => '১ সেকেন্ড|:count সেকেন্ড',
    's' => '১ সেকেন্ড|:count সেকেন্ড',
    'ago' => ':time পূর্বে',
    'from_now' => 'এখন থেকে :time',
    'after' => ':time পরে',
    'before' => ':time আগে',
    'diff_now' => 'এখন',
    'diff_yesterday' => 'গতকাল',
    'diff_tomorrow' => 'আগামীকাল',
    'period_recurrences' => ':count বার|:count বার',
    'period_interval' => 'প্রতি :interval',
    'period_start_date' => ':date থেকে',
    'period_end_date' => ':date পর্যন্ত',
);
