<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => ':count aasta|:count aastat',
    'y' => ':count aasta|:count aastat',
    'month' => ':count kuu|:count kuud',
    'm' => ':count kuu|:count kuud',
    'week' => ':count nädal|:count nädalat',
    'w' => ':count nädal|:count nädalat',
    'day' => ':count päev|:count päeva',
    'd' => ':count päev|:count päeva',
    'hour' => ':count tund|:count tundi',
    'h' => ':count tund|:count tundi',
    'minute' => ':count minut|:count minutit',
    'min' => ':count minut|:count minutit',
    'second' => ':count sekund|:count sekundit',
    's' => ':count sekund|:count sekundit',
    'ago' => ':time tagasi',
    'from_now' => ':time pärast',
    'after' => ':time pärast',
    'before' => ':time enne',
    'year_from_now' => ':count aasta',
    'month_from_now' => ':count kuu',
    'week_from_now' => ':count nädala',
    'day_from_now' => ':count päeva',
    'hour_from_now' => ':count tunni',
    'minute_from_now' => ':count minuti',
    'second_from_now' => ':count sekundi',
);
