<?php
/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
return array(
    'year' => '1 flwyddyn|:count blynedd',
    'y' => ':countbl',
    'month' => '1 mis|:count fis',
    'm' => ':countmi',
    'week' => ':count wythnos',
    'w' => ':countw',
    'day' => ':count diwrnod',
    'd' => ':countd',
    'hour' => ':count awr',
    'h' => ':counth',
    'minute' => ':count munud',
    'min' => ':countm',
    'second' => ':count eiliad',
    's' => ':counts',
    'ago' => ':time yn ôl',
    'from_now' => ':time o hyn ymlaen',
    'after' => ':time ar ôl',
    'before' => ':time o\'r blaen',
);
