<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => ':count an|:count ans',
    'y' => ':count an|:count ans',
    'month' => ':count mois',
    'm' => ':count mois',
    'week' => ':count semaine|:count semaines',
    'w' => ':count sem.',
    'day' => ':count jour|:count jours',
    'd' => ':count j.',
    'hour' => ':count heure|:count heures',
    'h' => ':count h.',
    'minute' => ':count minute|:count minutes',
    'min' => ':count min.',
    'second' => ':count seconde|:count secondes',
    's' => ':count sec.',
    'ago' => 'il y a :time',
    'from_now' => 'dans :time',
    'after' => ':time après',
    'before' => ':time avant',
    'diff_now' => "à l'instant",
    'diff_yesterday' => 'hier',
    'diff_tomorrow' => 'demain',
    'diff_before_yesterday' => 'avant-hier',
    'diff_after_tomorrow' => 'après-demain',
    'period_recurrences' => ':count fois',
    'period_interval' => 'tous les :interval',
    'period_start_date' => 'de :date',
    'period_end_date' => 'à :date',
);
