<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => ':count anno|:count anni',
    'y' => ':count anno|:count anni',
    'month' => ':count mese|:count mesi',
    'm' => ':count mese|:count mesi',
    'week' => ':count settimana|:count settimane',
    'w' => ':count settimana|:count settimane',
    'day' => ':count giorno|:count giorni',
    'd' => ':count giorno|:count giorni',
    'hour' => ':count ora|:count ore',
    'h' => ':count ora|:count ore',
    'minute' => ':count minuto|:count minuti',
    'min' => ':count minuto|:count minuti',
    'second' => ':count secondo|:count secondi',
    's' => ':count secondo|:count secondi',
    'ago' => ':time fa',
    'from_now' => 'tra :time',
    'after' => ':time dopo',
    'before' => ':time prima',
    'diff_now' => 'proprio ora',
    'diff_yesterday' => 'ieri',
    'diff_tomorrow' => 'domani',
    'diff_before_yesterday' => "l'altro ieri",
    'diff_after_tomorrow' => 'dopodomani',
);
