<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => 'Urte 1|:count urte',
    'y' => 'Urte 1|:count urte',
    'month' => 'Hile 1|:count hile',
    'm' => 'Hile 1|:count hile',
    'week' => 'Aste 1|:count aste',
    'w' => 'Aste 1|:count aste',
    'day' => 'Egun 1|:count egun',
    'd' => 'Egun 1|:count egun',
    'hour' => 'Ordu 1|:count ordu',
    'h' => 'Ordu 1|:count ordu',
    'minute' => 'Minutu 1|:count minutu',
    'min' => 'Minutu 1|:count minutu',
    'second' => 'Segundu 1|:count segundu',
    's' => 'Segundu 1|:count segundu',
    'ago' => 'Orain dela :time',
    'from_now' => ':time barru',
    'after' => ':time geroago',
    'before' => ':time lehenago',
);
