<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => 'rok|:count roky|:count rokov',
    'y' => 'rok|:count roky|:count rokov',
    'month' => 'mesiac|:count mesiace|:count mesiacov',
    'm' => 'mesiac|:count mesiace|:count mesiacov',
    'week' => 'týždeň|:count týždne|:count týždňov',
    'w' => 'týždeň|:count týždne|:count týždňov',
    'day' => 'deň|:count dni|:count dní',
    'd' => 'deň|:count dni|:count dní',
    'hour' => 'hodinu|:count hodiny|:count hodín',
    'h' => 'hodinu|:count hodiny|:count hodín',
    'minute' => 'minútu|:count minúty|:count minút',
    'min' => 'minútu|:count minúty|:count minút',
    'second' => 'sekundu|:count sekundy|:count sekúnd',
    's' => 'sekundu|:count sekundy|:count sekúnd',
    'ago' => 'pred :time',
    'from_now' => 'za :time',
    'after' => 'o :time neskôr',
    'before' => ':time predtým',
    'year_ago' => 'rokom|:count rokmi|:count rokmi',
    'month_ago' => 'mesiacom|:count mesiacmi|:count mesiacmi',
    'week_ago' => 'týždňom|:count týždňami|:count týždňami',
    'day_ago' => 'dňom|:count dňami|:count dňami',
    'hour_ago' => 'hodinou|:count hodinami|:count hodinami',
    'minute_ago' => 'minútou|:count minútami|:count minútami',
    'second_ago' => 'sekundou|:count sekundami|:count sekundami',
);
