<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => '1 वर्ष|:count वर्षों',
    'y' => '1 वर्ष|:count वर्षों',
    'month' => '1 माह|:count महीने',
    'm' => '1 माह|:count महीने',
    'week' => '1 सप्ताह|:count सप्ताह',
    'w' => '1 सप्ताह|:count सप्ताह',
    'day' => '1 दिन|:count दिनों',
    'd' => '1 दिन|:count दिनों',
    'hour' => '1 घंटा|:count घंटे',
    'h' => '1 घंटा|:count घंटे',
    'minute' => '1 मिनट|:count मिनटों',
    'min' => '1 मिनट|:count मिनटों',
    'second' => '1 सेकंड|:count सेकंड',
    's' => '1 सेकंड|:count सेकंड',
    'ago' => ':time पूर्व',
    'from_now' => ':time से',
    'after' => ':time के बाद',
    'before' => ':time के पहले',
);
