<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => ':count år|:count år',
    'y' => ':count år|:count år',
    'month' => ':count måned|:count måneder',
    'm' => ':count måned|:count måneder',
    'week' => ':count uke|:count uker',
    'w' => ':count uke|:count uker',
    'day' => ':count dag|:count dager',
    'd' => ':count dag|:count dager',
    'hour' => ':count time|:count timer',
    'h' => ':count time|:count timer',
    'minute' => ':count minutt|:count minutter',
    'min' => ':count minutt|:count minutter',
    'second' => ':count sekund|:count sekunder',
    's' => ':count sekund|:count sekunder',
    'ago' => ':time siden',
    'from_now' => 'om :time',
    'after' => ':time etter',
    'before' => ':time før',
    'diff_now' => 'akkurat nå',
    'diff_yesterday' => 'i går',
    'diff_tomorrow' => 'i morgen',
    'diff_before_yesterday' => 'i forgårs',
    'diff_after_tomorrow' => 'i overmorgen',
);
