<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => ':count leto|:count leti|:count leta|:count let',
    'y' => ':count leto|:count leti|:count leta|:count let',
    'month' => ':count mesec|:count meseca|:count mesece|:count mesecev',
    'm' => ':count mesec|:count meseca|:count mesece|:count mesecev',
    'week' => ':count teden|:count tedna|:count tedne|:count tednov',
    'w' => ':count teden|:count tedna|:count tedne|:count tednov',
    'day' => ':count dan|:count dni|:count dni|:count dni',
    'd' => ':count dan|:count dni|:count dni|:count dni',
    'hour' => ':count uro|:count uri|:count ure|:count ur',
    'h' => ':count uro|:count uri|:count ure|:count ur',
    'minute' => ':count minuto|:count minuti|:count minute|:count minut',
    'min' => ':count minuto|:count minuti|:count minute|:count minut',
    'second' => ':count sekundo|:count sekundi|:count sekunde|:count sekund',
    's' => ':count sekundo|:count sekundi|:count sekunde|:count sekund',
    'year_ago' => ':count letom|:count leti|:count leti|:count leti',
    'month_ago' => ':count mesecem|:count meseci|:count meseci|:count meseci',
    'week_ago' => ':count tednom|:count tednoma|:count tedni|:count tedni',
    'day_ago' => ':count dnem|:count dnevoma|:count dnevi|:count dnevi',
    'hour_ago' => ':count uro|:count urama|:count urami|:count urami',
    'minute_ago' => ':count minuto|:count minutama|:count minutami|:count minutami',
    'second_ago' => ':count sekundo|:count sekundama|:count sekundami|:count sekundami',
    'ago' => 'pred :time',
    'from_now' => 'čez :time',
    'after' => 'čez :time',
    'before' => 'pred :time',
    'diff_now' => 'ravnokar',
    'diff_yesterday' => 'včeraj',
    'diff_tomorrow' => 'jutri',
    'diff_before_yesterday' => 'predvčerajšnjim',
    'diff_after_tomorrow' => 'pojutrišnjem',
);
