<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => ':count rok|:count lata|:count lat',
    'y' => ':countr|:countl',
    'month' => ':count miesiąc|:count miesiące|:count miesięcy',
    'm' => ':countmies',
    'week' => ':count tydzień|:count tygodnie|:count tygodni',
    'w' => ':counttyg',
    'day' => ':count dzień|:count dni|:count dni',
    'd' => ':countd',
    'hour' => ':count godzina|:count godziny|:count godzin',
    'h' => ':countg',
    'minute' => ':count minuta|:count minuty|:count minut',
    'min' => ':countm',
    'second' => ':count sekunda|:count sekundy|:count sekund',
    's' => ':counts',
    'ago' => ':time temu',
    'from_now' => ':time od teraz',
    'after' => ':time po',
    'before' => ':time przed',
    'diff_now' => 'przed chwilą',
    'diff_yesterday' => 'wczoraj',
    'diff_tomorrow' => 'jutro',
    'diff_before_yesterday' => 'przedwczoraj',
    'diff_after_tomorrow' => 'pojutrze',
);
