<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Ahmed Ali <ajaaibu@gmail.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => '{0}އަހަރެއް|[1,Inf]:count އަހަރު',
    'y' => '{0}އަހަރެއް|[1,Inf]:count އަހަރު',
    'month' => '{0}މައްސަރެއް|[1,Inf]:count މަސް',
    'm' => '{0}މައްސަރެއް|[1,Inf]:count މަސް',
    'week' => '{0}ހަފްތާއެއް|[1,Inf]:count ހަފްތާ',
    'w' => '{0}ހަފްތާއެއް|[1,Inf]:count ހަފްތާ',
    'day' => '{0}ދުވަސް|[1,Inf]:count ދުވަސް',
    'd' => '{0}ދުވަސް|[1,Inf]:count ދުވަސް',
    'hour' => '{0}ގަޑިއިރެއް|[1,Inf]:count ގަޑި',
    'h' => '{0}ގަޑިއިރެއް|[1,Inf]:count ގަޑި',
    'minute' => '{0}މިނެޓެއް|[1,Inf]:count މިނެޓް',
    'min' => '{0}މިނެޓެއް|[1,Inf]:count މިނެޓް',
    'second' => '{0}ސިކުންތެއް|[1,Inf]:count ސިކުންތު',
    's' => '{0}ސިކުންތެއް|[1,Inf]:count ސިކުންތު',
    'ago' => ':time ކުރިން',
    'from_now' => ':time ފަހުން',
    'after' => ':time ފަހުން',
    'before' => ':time ކުރި',
);
