<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => 'un an|:count ani|:count ani',
    'y' => 'un an|:count ani|:count ani',
    'month' => 'o lună|:count luni|:count luni',
    'm' => 'o lună|:count luni|:count luni',
    'week' => 'o săptămână|:count săptămâni|:count săptămâni',
    'w' => 'o săptămână|:count săptămâni|:count săptămâni',
    'day' => 'o zi|:count zile|:count zile',
    'd' => 'o zi|:count zile|:count zile',
    'hour' => 'o oră|:count ore|:count ore',
    'h' => 'o oră|:count ore|:count ore',
    'minute' => 'un minut|:count minute|:count minute',
    'min' => 'un minut|:count minute|:count minute',
    'second' => 'o secundă|:count secunde|:count secunde',
    's' => 'o secundă|:count secunde|:count secunde',
    'ago' => 'acum :time',
    'from_now' => ':time de acum',
    'after' => 'peste :time',
    'before' => 'acum :time',
);
