<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => ':count jaar',
    'y' => ':count jaar',
    'month' => ':count maand|:count maanden',
    'm' => ':count maand|:count maanden',
    'week' => ':count week|:count weken',
    'w' => ':count week|:count weken',
    'day' => ':count dag|:count dagen',
    'd' => ':count dag|:count dagen',
    'hour' => ':count uur',
    'h' => ':count uur',
    'minute' => ':count minuut|:count minuten',
    'min' => ':count minuut|:count minuten',
    'second' => ':count seconde|:count seconden',
    's' => ':count seconde|:count seconden',
    'ago' => ':time geleden',
    'from_now' => 'over :time',
    'after' => ':time later',
    'before' => ':time eerder',
    'diff_now' => 'nu',
    'diff_yesterday' => 'gisteren',
    'diff_tomorrow' => 'morgen',
    'diff_after_tomorrow' => 'overmorgen',
    'diff_before_yesterday' => 'eergisteren',
);
