<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => ':count વર્ષ|:count વર્ષો',
    'y' => ':countવર્ષ|:countવર્ષો',
    'month' => ':count મહિનો|:count મહિના',
    'm' => ':countમહિનો|:countમહિના',
    'week' => ':count અઠવાડિયું|:count અઠવાડિયા',
    'w' => ':countઅઠ.|:countઅઠ.',
    'day' => ':count દિવસ|:count દિવસો',
    'd' => ':countદિ.|:countદિ.',
    'hour' => ':count કલાક|:count કલાકો',
    'h' => ':countક.|:countક.',
    'minute' => ':count મિનિટ|:count મિનિટ',
    'min' => ':countમિ.|:countમિ.',
    'second' => ':count સેકેન્ડ|:count સેકેન્ડ',
    's' => ':countસે.|:countસે.',
    'ago' => ':time પહેલા',
    'from_now' => ':time અત્યારથી',
    'after' => ':time પછી',
    'before' => ':time પહેલા',
);
