<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => 'mwaka 1|miaka :count',
    'y' => 'mwaka 1|miaka :count',
    'month' => 'mwezi 1|miezi :count',
    'm' => 'mwezi 1|miezi :count',
    'week' => 'wiki 1|wiki :count',
    'w' => 'wiki 1|wiki :count',
    'day' => 'siku 1|siku :count',
    'd' => 'siku 1|siku :count',
    'hour' => 'saa 1|masaa :count',
    'h' => 'saa 1|masaa :count',
    'minute' => 'dakika 1|dakika :count',
    'min' => 'dakika 1|dakika :count',
    'second' => 'sekunde 1|sekunde :count',
    's' => 'sekunde 1|sekunde :count',
    'ago' => ':time ziliyopita',
    'from_now' => ':time kwanzia sasa',
    'after' => ':time baada',
    'before' => ':time kabla',
);
