<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => ':count χρόνος|:count χρόνια',
    'y' => ':count χρόνος|:count χρόνια',
    'month' => ':count μήνας|:count μήνες',
    'm' => ':count μήνας|:count μήνες',
    'week' => ':count εβδομάδα|:count εβδομάδες',
    'w' => ':count εβδομάδα|:count εβδομάδες',
    'day' => ':count μέρα|:count μέρες',
    'd' => ':count μέρα|:count μέρες',
    'hour' => ':count ώρα|:count ώρες',
    'h' => ':count ώρα|:count ώρες',
    'minute' => ':count λεπτό|:count λεπτά',
    'min' => ':count λεπτό|:count λεπτά',
    'second' => ':count δευτερόλεπτο|:count δευτερόλεπτα',
    's' => ':count δευτερόλεπτο|:count δευτερόλεπτα',
    'ago' => 'πριν από :time',
    'from_now' => 'σε :time από τώρα',
    'after' => ':time μετά',
    'before' => ':time πριν',
);
