<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => ':count jaro|:count jaroj',
    'y' => ':count jaro|:count jaroj',
    'month' => ':count monato|:count monatoj',
    'm' => ':count monato|:count monatoj',
    'week' => ':count semajno|:count semajnoj',
    'w' => ':count semajno|:count semajnoj',
    'day' => ':count tago|:count tagoj',
    'd' => ':count tago|:count tagoj',
    'hour' => ':count horo|:count horoj',
    'h' => ':count horo|:count horoj',
    'minute' => ':count minuto|:count minutoj',
    'min' => ':count minuto|:count minutoj',
    'second' => ':count sekundo|:count sekundoj',
    's' => ':count sekundo|:count sekundoj',
    'ago' => 'antaŭ :time',
    'from_now' => 'je :time',
    'after' => ':time poste',
    'before' => ':time antaŭe',
);
