<?php

/*
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

return array(
    'year' => ':count vuosi|:count vuotta',
    'y' => ':count vuosi|:count vuotta',
    'month' => ':count kuukausi|:count kuukautta',
    'm' => ':count kuukausi|:count kuukautta',
    'week' => ':count viikko|:count viikkoa',
    'w' => ':count viikko|:count viikkoa',
    'day' => ':count päivä|:count päivää',
    'd' => ':count päivä|:count päivää',
    'hour' => ':count tunti|:count tuntia',
    'h' => ':count tunti|:count tuntia',
    'minute' => ':count minuutti|:count minuuttia',
    'min' => ':count minuutti|:count minuuttia',
    'second' => ':count sekunti|:count sekuntia',
    's' => ':count sekunti|:count sekuntia',
    'ago' => ':time sitten',
    'from_now' => ':time tästä hetkestä',
    'after' => ':time sen jälkeen',
    'before' => ':time ennen',
);
